"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("./types");
function renderCompiledTemplateSync(compiled, options) {
    const { expressionEvaluator } = options;
    let renderedTemplate = '';
    compiled.nodes.forEach(node => {
        if (node.type === types_1.MuttonCompiledNodeType.LITERAL) {
            renderedTemplate += node.literal;
        }
        else {
            const expressionNode = node;
            const evaluated = expressionEvaluator(expressionNode.expression);
            if (compiled.nodes.length === 1) {
                renderedTemplate = evaluated;
            }
            else {
                renderedTemplate += evaluated;
            }
        }
    });
    return renderedTemplate;
}
exports.renderCompiledTemplateSync = renderCompiledTemplateSync;
async function renderCompiledTemplateAsync(compiled, options) {
    const { expressionEvaluator } = options;
    let renderedTemplate = '';
    for (const node of compiled.nodes) {
        if (node.type === types_1.MuttonCompiledNodeType.LITERAL) {
            renderedTemplate += node.literal;
        }
        else {
            const expressionNode = node;
            const evaluated = await expressionEvaluator(expressionNode.expression);
            if (compiled.nodes.length === 1) {
                renderedTemplate = evaluated;
            }
            else {
                renderedTemplate += evaluated;
            }
        }
    }
    return renderedTemplate;
}
exports.renderCompiledTemplateAsync = renderCompiledTemplateAsync;
