"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require("./");
test('should allow rendering a compiled template async', async () => {
    const compiled = _1.compileTemplate('{{hopper}}');
    const expressionCalls = [];
    const result = await _1.renderCompiledTemplateAsync(compiled, {
        expressionEvaluator(expression) {
            expressionCalls.push(expression);
            return new Promise(resolve => {
                setTimeout(() => {
                    resolve(expression);
                }, 100);
            });
        },
    });
    expect(expressionCalls).toEqual(['hopper']);
    expect(result).toEqual('hopper');
});
test('should allow rendering a compiled template async with literal nodes', async () => {
    const compiled = _1.compileTemplate('Hello {{hopper}}');
    const expressionCalls = [];
    const result = await _1.renderCompiledTemplateAsync(compiled, {
        expressionEvaluator(expression) {
            expressionCalls.push(expression);
            return new Promise(resolve => {
                setTimeout(() => {
                    resolve(expression);
                }, 100);
            });
        },
    });
    expect(expressionCalls).toEqual(['hopper']);
    expect(result).toEqual('Hello hopper');
});
test('should preserve original expression value type if single expression alone in async render', async () => {
    const compiled = _1.compileTemplate('{{age}}');
    const expressionCalls = [];
    const result = await _1.renderCompiledTemplateAsync(compiled, {
        expressionEvaluator(expression) {
            expressionCalls.push(expression);
            return new Promise(resolve => {
                setTimeout(() => {
                    resolve(9001);
                }, 100);
            });
        },
    });
    expect(expressionCalls).toEqual(['age']);
    expect(result).toEqual(9001);
});
